base64_decoder

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: MIT Imports: 4 Imported by: 0

README

Base64 Decoder Secret Modifier (b64d)

The b64d modifier decodes a base64-encoded secret value.

Usage

To use it, append the modifier b64d to the given secret coordinates string:

plain://bXktc2VjcmV0?b64d

Behavior

  • It takes the retrieved secret value and decodes it using Go's standard encoding/base64 package.
  • If the secret value is not a valid base64 string, the modifier will return an ErrSecretModifierBase64DecoderFailedDecoding error.
  • Any modifier arguments (e.g. ?b64d=foo) are currently ignored.

Documentation

Index

Constants

This section is empty.

Variables

var ErrSecretModifierBase64DecoderFailedDecoding = fmt.Errorf("failed to decode base64 secret")

Functions

This section is empty.

Types

type SecretModifierBase64Decoder

type SecretModifierBase64Decoder struct{}

SecretModifierBase64Decoder is a modifier that decodes a base64 string to a secret value.

To use it, append the modifier `b64d` to the given secret coordinates string:

plain://bXktc2VjcmV0?b64d

func (*SecretModifierBase64Decoder) Modify

func (s *SecretModifierBase64Decoder) Modify(
	_ context.Context,
	secretValue string,
	_ string,
) (string, error)

func (*SecretModifierBase64Decoder) Type

Jump to