Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func WithXPath ¶
func WithXPath() spelunk.SpelunkerOption
WithXPath adds the XPath modifier to a Spelunker.
Types ¶
type SecretModifierXPath ¶
type SecretModifierXPath struct{}
SecretModifierXPath is a modifier that can extract a specific field out of an XML stored in a secret value. After the secret has been dug-up, the modifier digs further at the provided XPath, and returns the inner text found there.
func (*SecretModifierXPath) Type ¶
func (s *SecretModifierXPath) Type() string
Click to show internal directories.
Click to hide internal directories.